@@ -12,7 +12,7 @@ import datetime
 import shutil
 import sys
 import socket
-
+import re
 socket.setdefaulttimeout(30)
 
 supports_alpha = False
@@ -209,6 +209,8 @@ comics = {
 		"zitsckdm":{"name":"Zits","link":'http://content.comicskingdom.net/Zits/',"start":"20100921","dbfile":dbdir + "comicdb.zits.csv"},
 		"viivijawagnerhesari":{"name":"Viivi ja Wagner","link":"http://www.hs.fi/viivijawagner/","start":"1135260260615","dbfile":dbdir + "comicdb.viivijawagner.csv"},
 		"fingerporihesari":{"name":"Fingerpori","link":"http://www.hs.fi/fingerpori/","start":"1135260260580","dbfile":dbdir + "comicdb.fingerpori.csv"},
+		"exocomics":{"name":"Extra Ordinary","link":"http://exocomics.com/","start":"146","dbfile":dbdir + "comicdb.exocomics.csv"},
+		"qcontent":{"name":"Questionable Content","link":"http://questionablecontent.net/view.php?comic=","start":"1758","dbfile":dbdir + "comicdb.qcontent.csv"},
 
 
 
@@ -860,8 +862,9 @@ class ComicDb():
 			if d > today:
 				print "Fetching the future! Break break break!"
 				return False
+
 		else:
-			return False
+			link = comics[comic]['link'] + str(number)
 
 		print "link: " + link
 		#try:
@@ -1040,6 +1043,27 @@ class ComicDb():
 			elif comic[-4:] == 'ckdm':
 				url = link
 				title = number[:4] + "-" + number[4:6] + "-" + number[6:8]
+			elif comic == 'exocomics':
+				s = f.read()
+				f.close()
+				splt = string.split(s, '<div class="object align="center"><a href="http://exocomics.com/' + str(number + 1) + '"><img src="', 1)
+				if len(splt) < 2:
+					splt = string.split(s, '<div class="object align="center"><a href="http://exocomics.com/' + str(number) + '"><img src="', 1)
+				splt = string.split(splt[1], '" width="900" height="', 1)
+				url = splt[0]
+				splt = string.split(splt[1], 'alt="' + str(number) + '" title="', 1)
+				splt = string.split(splt[1], '" class="comic-item', 1)
+				title = splt[0]
+			elif comic == 'qcontent':
+				s = f.read()
+				f.close()
+				url = "http://questionablecontent.net/comics/" + str(number) + ".png"
+				splt = string.split(s, '<div id="news">', 1)
+				splt = string.split(splt[1], '</div>', 1)
+				title = re.sub(r'<[^>]*?>', '', splt[0])
+				title = title.strip()
+				if title == "No news today, sorry.":
+					return False
 			splt2 = string.rsplit(url, "/", 1)
 			filename = splt2[1]
 			try:
